@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2013-2023  Charlie Sharpsteen, Stefan Löffler
+ * Copyright (C) 2013-2024  Charlie Sharpsteen, Stefan Löffler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -17,6 +17,8 @@
 
 #include <QBitArray>
 
+#include <QDomDocument>
+
 #if defined(HAVE_POPPLER_XPDF_HEADERS) && defined(Q_OS_DARWIN)
 #include "poppler-config.h"
 #include "GlobalParams.h"
@@ -204,6 +206,7 @@ void Document::reload()
 void Document::parseDocument()
 {
   QWriteLocker docLocker(_docLock.data());
+  using poppler_size_type = decltype(_poppler_doc->numPages());
 
   clearMetaData();
   _meta_fileSize = QFileInfo(_fileName).size();
@@ -278,15 +281,69 @@ void Document::parseDocument()
     metaKeys.removeAll(QString::fromUtf8("ModDate"));
   }
 
+  const QString xmpMetadata = _poppler_doc->metadata();
+  if (!xmpMetadata.isEmpty()) {
+    QDomDocument domDoc;
+    const auto getMetadataEntry = [&domDoc](const QString & nsURI, const QString & tag) {
+      const QDomNodeList nodes = domDoc.elementsByTagName(tag);
+      QString retVal;
+      for (int iNode = 0; iNode < nodes.size(); ++iNode) {
+        const QDomNode node = nodes.at(iNode);
+        // NB: Use startsWith() as full namespaces may contain version info
+        // which we don't care about here
+        if (!node.namespaceURI().startsWith(nsURI)) {
+          continue;
+        }
+        const QDomElement el = nodes.at(iNode).toElement();
+        retVal += el.text();
+      }
+      return retVal;
+    };
+    const auto setMetadataString = [&getMetadataEntry](const QString & nsURI, const QString & tag, QString & entry) {
+      const QString str{getMetadataEntry(nsURI, tag)};
+      if (!str.isEmpty()) {
+        entry = str;
+      }
+    };
+    const auto setMetadataDatetime = [&getMetadataEntry](const QString & nsURI, const QString & tag, QDateTime & datetime) {
+      const QString str{getMetadataEntry(nsURI, tag)};
+      const QDateTime dt{QDateTime::fromString(str, Qt::ISODate)};
+      if (dt.isValid()) {
+        datetime = dt;
+      }
+    };
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
+    QString errMsg;
+    int errLine{0}, errCol{0};
+    if (domDoc.setContent(_poppler_doc->metadata(), true, &errMsg, &errLine, &errCol)) {
+#else
+    if (domDoc.setContent(_poppler_doc->metadata(), QDomDocument::ParseOption::UseNamespaceProcessing)) {
+#endif
+      const QString dcNS{QStringLiteral("http://purl.org/dc/")};
+      const QString xmpNS{QStringLiteral("http://ns.adobe.com/xap/")};
+      const QString pdfNS{QStringLiteral("http://ns.adobe.com/pdf/")};
+
+      setMetadataString(dcNS, QStringLiteral("title"), _meta_title);
+      setMetadataString(dcNS, QStringLiteral("creator"), _meta_author);
+      setMetadataString(dcNS, QStringLiteral("description"), _meta_subject);
+      setMetadataString(dcNS, QStringLiteral("subject"), _meta_keywords);
+      setMetadataString(xmpNS, QStringLiteral("CreatorTool"), _meta_creator);
+      setMetadataString(pdfNS, QStringLiteral("Producer"), _meta_producer);
+      setMetadataDatetime(xmpNS, QStringLiteral("CreateDate"), _meta_creationDate);
+      setMetadataDatetime(xmpNS, QStringLiteral("ModifyDate"), _meta_modDate);
+    }
+  }
+
   // Get the most often used page size
-  QMap<QSizeF, int> pageSizes;
-  for (int i = 0; i < _numPages; ++i) {
+  QMap<QSizeF, size_type> pageSizes;
+  for (poppler_size_type i = 0; i < _numPages; ++i) {
     const std::unique_ptr<::Poppler::Page> page{_poppler_doc->page(i)};
     QSizeF ps = page->pageSizeF();
     if (pageSizes.contains(ps)) ++pageSizes[ps];
     else pageSizes[ps] = 1;
   }
-  int occurrences = -1;
+  size_type occurrences = -1;
   _meta_pageSize = QSizeF();
   Q_FOREACH(QSizeF ps, pageSizes.keys()) {
       if (occurrences < pageSizes[ps]) {
@@ -305,7 +362,7 @@ void Document::parseDocument()
     _meta_other[key] = _poppler_doc->info(key);
 }
 
-QWeakPointer<Backend::Page> Document::page(int at)
+QWeakPointer<Backend::Page> Document::page(size_type at)
 {
   {
     QReadLocker docLocker(_docLock.data());
@@ -526,6 +583,18 @@ QList<PDFFontInfo> Document::fonts() const
   return _fonts;
 }
 
+QAbstractItemModel *Document::optionalContentModel() const
+{
+  if (!_poppler_doc) {
+    return nullptr;
+  }
+  QMutexLocker l(_poppler_docLock);
+  if (_poppler_doc->isLocked() || !_poppler_doc->hasOptionalContent()) {
+    return nullptr;
+  }
+  return _poppler_doc->optionalContentModel();
+}
+
 QColor Document::paperColor() const
 {
   if (!_poppler_doc) {
@@ -567,10 +636,12 @@ bool Document::unlock(const QString password)
 
 // Page Class
 // ==========
-Page::Page(Document *parent, int at, QSharedPointer<QReadWriteLock> docLock):
+Page::Page(Document *parent, size_type at, QSharedPointer<QReadWriteLock> docLock):
   Super(parent, at, docLock)
 {
-  _poppler_page = std::unique_ptr< ::Poppler::Page >(dynamic_cast<Document *>(_parent)->_poppler_doc->page(at));
+  const auto & poppler_doc = dynamic_cast<Document *>(_parent)->_poppler_doc;
+  using poppler_size_type = decltype(poppler_doc->numPages());
+  _poppler_page = std::unique_ptr<::Poppler::Page>(poppler_doc->page(static_cast<poppler_size_type>(at)));
   loadTransitionData();
 }
 
@@ -645,7 +716,7 @@ QList< QSharedPointer<Annotation::Link> > Page::loadLinks()
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QList<::Poppler::Link *> poppler_links = _poppler_page->links();
     std::vector< std::unique_ptr<::Poppler::Link> > rv;
-    rv.reserve(poppler_links.size());
+    rv.reserve(static_cast<decltype(rv)::size_type>(poppler_links.size()));
     for (::Poppler::Link * link : poppler_links) {
       rv.emplace_back(link);
     }
@@ -660,7 +731,7 @@ QList< QSharedPointer<Annotation::Link> > Page::loadLinks()
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QList<::Poppler::Annotation *> poppler_annots = _poppler_page->annotations();
     std::vector< std::unique_ptr<::Poppler::Annotation> > rv;
-    rv.reserve(poppler_annots.size());
+    rv.reserve(static_cast<decltype(rv)::size_type>(poppler_annots.size()));
     for (::Poppler::Annotation * annot : poppler_annots) {
       rv.emplace_back(annot);
     }
@@ -740,6 +811,64 @@ QList< QSharedPointer<Annotation::Link> > Page::loadLinks()
       case ::Poppler::Link::JavaScript:
       case ::Poppler::Link::Rendition: // Since poppler 0.20
       */
+#if POPPLER_HAS_OCGSTATELINK
+      case ::Poppler::Link::OCGState: // Since poppler-qt 0.50
+      {
+        PDFOCGAction::MapType map;
+        std::vector<QVariant> origState;
+        using OrigStateSizeType = std::vector<QVariant>::size_type;
+        Document * popplerDoc = dynamic_cast<Backend::PopplerQt::Document *>(_parent);
+        Poppler::OptContentModel * ocgModel = popplerDoc->_poppler_doc->optionalContentModel();
+        if (!ocgModel) {
+          break;
+        }
+
+        // Save original state
+        if (ocgModel->rowCount() > 0) {
+          origState.reserve(static_cast<OrigStateSizeType>(ocgModel->rowCount()));
+        }
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          origState.push_back(ocgModel->data(ocgModel->index(row, 0, {}), Qt::CheckStateRole));
+        }
+
+        // 1) Toggle alls ocg's off, apply poppler state change, and see which
+        // ones were turned back on
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          ocgModel->setData(ocgModel->index(row, 0, {}), Qt::Unchecked, Qt::CheckStateRole);
+        }
+        ocgModel->applyLink(dynamic_cast<::Poppler::LinkOCGState*>(popplerLink.get()));
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          if (ocgModel->data(ocgModel->index(row, 0, {}), Qt::CheckStateRole) == QVariant(Qt::Checked)) {
+            map.insert({row, PDFOCGAction::OCGStateChange::Show});
+          }
+        }
+
+        // 2) Toggle alls ocg's on, apply poppler state change, and see which
+        // ones were turned back off
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          ocgModel->setData(ocgModel->index(row, 0, {}), Qt::Checked, Qt::CheckStateRole);
+        }
+        ocgModel->applyLink(dynamic_cast<::Poppler::LinkOCGState*>(popplerLink.get()));
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          if (ocgModel->data(ocgModel->index(row, 0, {}), Qt::CheckStateRole) == QVariant(Qt::Unchecked)) {
+            if (map.find(row) != map.end()) {
+              map[row] = PDFOCGAction::OCGStateChange::Toggle;
+            }
+            else {
+              map.insert({row, PDFOCGAction::OCGStateChange::Hide});
+            }
+          }
+        }
+
+        // Restore original state
+        for (int row = 0; row < ocgModel->rowCount(); ++row) {
+          ocgModel->setData(ocgModel->index(row, 0, {}), origState[static_cast<OrigStateSizeType>(row)], Qt::CheckStateRole);
+        }
+
+        link->setActionOnActivation(new PDFOCGAction(map));
+        break;
+      }
+#endif // POPPLER_HAS_OCGSTATELINK
       default:
         // We don't handle these types yet
         link.clear();
@@ -774,7 +903,7 @@ QList< QSharedPointer<Annotation::AbstractAnnotation> > Page::loadAnnotations()
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QList<::Poppler::Annotation *> poppler_annots = _poppler_page->annotations();
     std::vector< std::unique_ptr<::Poppler::Annotation> > rv;
-    rv.reserve(poppler_annots.size());
+    rv.reserve(static_cast<decltype(rv)::size_type>(poppler_annots.size()));
     for (::Poppler::Annotation * annot : poppler_annots) {
       rv.emplace_back(annot);
     }
@@ -881,7 +1010,7 @@ QList<SearchResult> Page::search(const QString & searchText, const SearchFlags &
   if (!_parent)
     return results;
 
-  result.pageNum = static_cast<unsigned int>(_n);
+  result.pageNum = _n;
 
   QMutexLocker popplerDocLock(dynamic_cast<Document *>(_parent)->_poppler_docLock);
 
@@ -999,7 +1128,7 @@ QList< Backend::Page::Box > Page::boxes() const
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QList<::Poppler::TextBox*> popplerList = _poppler_page->textList();
     std::vector< std::unique_ptr<::Poppler::TextBox> > rv;
-    rv.reserve(popplerList.size());
+    rv.reserve(static_cast<decltype(rv)::size_type>(popplerList.size()));
     for (::Poppler::TextBox* box : popplerList) {
       rv.emplace_back(box);
     }
@@ -1024,10 +1153,11 @@ QList< Backend::Page::Box > Page::boxes() const
   return retVal;
 }
 
-QString Page::selectedText(const QList<QPolygonF> & selection, QMap<int, QRectF> * wordBoxes /* = nullptr */, QMap<int, QRectF> * charBoxes /* = nullptr */, const bool onlyFullyEnclosed /* = false */) const
+QString Page::selectedText(const QList<QPolygonF> & selection, BoxBoundaryList * wordBoxes /* = nullptr */, BoxBoundaryList * charBoxes /* = nullptr */, const bool onlyFullyEnclosed /* = false */) const
 {
   QReadLocker pageLocker(&_pageLock);
   Q_ASSERT(_poppler_page != nullptr);
+  using poppler_size_type = decltype(dynamic_cast<Document*>(_parent)->_poppler_doc->numPages());
   // Using the bounding rects of the selection polygons is almost
   // certainly wrong! However, poppler-qt4 doesn't offer any alternative AFAICS
   // (except for positioning each char in the string manually).
@@ -1037,12 +1167,19 @@ QString Page::selectedText(const QList<QPolygonF> & selection, QMap<int, QRectF>
   QString retVal;
   bool insertSpace = false;
 
+  if (wordBoxes) {
+    wordBoxes->clear();
+  }
+  if (charBoxes) {
+    charBoxes->clear();
+  }
+
   // Get a list of all boxes
   const std::vector< std::unique_ptr<::Poppler::TextBox> > poppler_boxes = [&]() {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QList<::Poppler::TextBox*> popplerList = _poppler_page->textList();
     std::vector< std::unique_ptr<::Poppler::TextBox> > rv;
-    rv.reserve(popplerList.size());
+    rv.reserve(static_cast<decltype(rv)::size_type>(popplerList.size()));
     for (::Poppler::TextBox* box : popplerList) {
       rv.emplace_back(box);
     }
@@ -1060,7 +1197,7 @@ QString Page::selectedText(const QList<QPolygonF> & selection, QMap<int, QRectF>
 
     // Determine which characters to include (if any)
     QBitArray include(poppler_box->text().length());
-    for (int i = 0; i < poppler_box->text().length(); ++i) {
+    for (poppler_size_type i = 0; i < poppler_box->text().length(); ++i) {
       QPolygonF remainder(poppler_box->charBoundingBox(i));
       foreach (const QPolygonF & p, selection) {
         // Include characters if they are entirely inside the selection area or
@@ -1096,9 +1233,9 @@ QString Page::selectedText(const QList<QPolygonF> & selection, QMap<int, QRectF>
       retVal += QString::fromLatin1("\n");
 
       if (wordBoxes)
-        (*wordBoxes)[wordBoxes->count()] = lastPopplerBox->boundingBox();
+        (*wordBoxes).append(lastPopplerBox->boundingBox());
       if (charBoxes)
-        (*charBoxes)[charBoxes->count()] = lastPopplerBox->boundingBox();
+        (*charBoxes).append(lastPopplerBox->boundingBox());
       // If we queued a space to be inserted, ignore that as we inserted a
       // newline instead anyway
       insertSpace = false;
@@ -1110,24 +1247,24 @@ QString Page::selectedText(const QList<QPolygonF> & selection, QMap<int, QRectF>
       // As word and char Boxes, insert those of the lastPopplerBox since that
       // was the one causing insertSpace to be true
       if (wordBoxes)
-        (*wordBoxes)[wordBoxes->count()] = lastPopplerBox->boundingBox();
+        (*wordBoxes).append(lastPopplerBox->boundingBox());
       if (charBoxes)
-        (*charBoxes)[charBoxes->count()] = lastPopplerBox->boundingBox();
+        (*charBoxes).append(lastPopplerBox->boundingBox());
     }
 
     // Default to not inserting a space after this word
     insertSpace = false;
 
     // Insert the actual characters
-    for (int i = 0; i < poppler_box->text().length(); ++i) {
+    for (poppler_size_type i = 0; i < poppler_box->text().length(); ++i) {
       if (!include.testBit(i)) continue;
 
       retVal += poppler_box->text()[i];
 
       if (wordBoxes)
-        (*wordBoxes)[wordBoxes->count()] = poppler_box->boundingBox();
+        (*wordBoxes).append(poppler_box->boundingBox());
       if (charBoxes)
-        (*charBoxes)[charBoxes->count()] = poppler_box->charBoundingBox(i);
+        (*charBoxes).append(poppler_box->charBoundingBox(i));
 
       // If we reached the end of the word, possibly queue a space to be
       // inserted. By queuing this until the next word is processed, we ensure
