@@ -19,17 +19,17 @@
         <translation>Posició:</translation>
     </message>
     <message>
-        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
+        <location filename="../src/GuidelineEditDialog.ui" line="59"/>
         <source>cm</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
+        <location filename="../src/GuidelineEditDialog.ui" line="64"/>
         <source>in</source>
         <translation>in (polsades)</translation>
     </message>
     <message>
-        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
+        <location filename="../src/GuidelineEditDialog.ui" line="69"/>
         <source>bp</source>
         <translation></translation>
     </message>
@@ -752,12 +752,12 @@
 <context>
     <name>QtPDF</name>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="33"/>
+        <location filename="../src/PDFDocumentView.cpp" line="34"/>
         <source>[language name]</source>
         <translation>català</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="34"/>
+        <location filename="../src/PDFDocumentView.cpp" line="35"/>
         <source>[translator&apos;s name/email]</source>
         <translation>Ignasi Furió</translation>
     </message>
@@ -765,37 +765,37 @@
 <context>
     <name>QtPDF::PDFDocumentScene</name>
     <message>
-        <location filename="../src/PDFBackend.cpp" line="321"/>
+        <location filename="../src/PDFBackend.cpp" line="326"/>
         <source>rendering page</source>
         <translation>pàgina en construcció</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="246"/>
         <source>Unlock PDF</source>
         <translation>Desbloqueja PDF</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="246"/>
         <source>Please enter the password to unlock the PDF</source>
         <translation>Si us plau, introdueixi la contrassenya per desbloquejar el PDF</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="262"/>
         <source>Incorrect password</source>
         <translation>Contrassenya incorrecta</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="262"/>
         <source>The password you entered was incorrect.</source>
         <translation>La contrassenya introduida és incorrecta.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="268"/>
         <source>This document is locked. You need a password to open it.</source>
         <translation>El document està bloquejat. Cal una contrassenya per obrir-lo.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2036"/>
+        <location filename="../src/PDFDocumentScene.cpp" line="269"/>
         <source>Unlock</source>
         <translation>Desbloquejar</translation>
     </message>
@@ -803,323 +803,328 @@
 <context>
     <name>QtPDF::PDFDocumentView</name>
     <message>
-        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
+        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
         <source>Insufficient permission</source>
         <translation>Permisos insuficients</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
+        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
         <source>Text extraction is not allowed for this document.</source>
         <translation>No està permès extreure el text d&apos;aquest document.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2577"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2264"/>
         <source>Goto page %1</source>
         <translation>Ves a pàgina %1</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2589"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2276"/>
         <source>Execute `%1`</source>
         <translation>Executa `%1`</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2835"/>
-        <location filename="../src/PDFDocumentView.cpp" line="2852"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2541"/>
+        <source>Layers</source>
+        <translation>Capes</translation>
+    </message>
+    <message>
+        <location filename="../src/InfoWidgets.cpp" line="54"/>
+        <location filename="../src/InfoWidgets.cpp" line="71"/>
         <source>Table of Contents</source>
         <translation>Taula de continguts</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2944"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3151"/>
+        <location filename="../src/InfoWidgets.cpp" line="163"/>
+        <location filename="../src/InfoWidgets.cpp" line="370"/>
         <source>Meta Data</source>
         <translation>Meta dades</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3000"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
+        <location filename="../src/InfoWidgets.cpp" line="219"/>
+        <location filename="../src/InfoWidgets.cpp" line="380"/>
         <source>Processing</source>
         <translation>Processant</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3032"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
+        <location filename="../src/InfoWidgets.cpp" line="251"/>
+        <location filename="../src/InfoWidgets.cpp" line="387"/>
         <source>Other</source>
         <translation>Altres</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3057"/>
+        <location filename="../src/InfoWidgets.cpp" line="276"/>
         <source>B</source>
         <extracomment>File size: bytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3059"/>
+        <location filename="../src/InfoWidgets.cpp" line="278"/>
         <source>kB</source>
         <extracomment>File size: kilobytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3061"/>
+        <location filename="../src/InfoWidgets.cpp" line="280"/>
         <source>MB</source>
         <extracomment>File size: megabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3063"/>
+        <location filename="../src/InfoWidgets.cpp" line="282"/>
         <source>GB</source>
         <extracomment>File size: gigabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3065"/>
+        <location filename="../src/InfoWidgets.cpp" line="284"/>
         <source>TB</source>
         <extracomment>File size: terabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3095"/>
+        <location filename="../src/InfoWidgets.cpp" line="314"/>
         <source>Yes</source>
         <translation>Sí</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3098"/>
+        <location filename="../src/InfoWidgets.cpp" line="317"/>
         <source>No</source>
         <translation>No</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3101"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3138"/>
+        <location filename="../src/InfoWidgets.cpp" line="320"/>
+        <location filename="../src/InfoWidgets.cpp" line="357"/>
         <source>Unknown</source>
         <translation>Desconegut</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3153"/>
+        <location filename="../src/InfoWidgets.cpp" line="372"/>
         <source>Document</source>
         <translation>Document</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3154"/>
+        <location filename="../src/InfoWidgets.cpp" line="373"/>
         <source>Title:</source>
         <translation>Títol:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3155"/>
+        <location filename="../src/InfoWidgets.cpp" line="374"/>
         <source>Author:</source>
         <translation>Autor:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3156"/>
+        <location filename="../src/InfoWidgets.cpp" line="375"/>
         <source>Subject:</source>
         <translation>Assumpte:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3157"/>
+        <location filename="../src/InfoWidgets.cpp" line="376"/>
         <source>Keywords:</source>
         <translation>Paraules clau:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
+        <location filename="../src/InfoWidgets.cpp" line="377"/>
         <source>Page size:</source>
         <translation>Mida pàgina:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3159"/>
+        <location filename="../src/InfoWidgets.cpp" line="378"/>
         <source>File size:</source>
         <translation>Mida Fitxer:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3162"/>
+        <location filename="../src/InfoWidgets.cpp" line="381"/>
         <source>Creator:</source>
         <translation>Creador:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
+        <location filename="../src/InfoWidgets.cpp" line="382"/>
         <source>Producer:</source>
         <translation>Productor:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
+        <location filename="../src/InfoWidgets.cpp" line="383"/>
         <source>Creation date:</source>
         <translation>Data de creació:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
+        <location filename="../src/InfoWidgets.cpp" line="384"/>
         <source>Modification date:</source>
         <translation>Data de modificació:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
+        <location filename="../src/InfoWidgets.cpp" line="385"/>
         <source>Trapped:</source>
         <translation>Atrapat:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3271"/>
+        <location filename="../src/InfoWidgets.cpp" line="396"/>
+        <location filename="../src/InfoWidgets.cpp" line="490"/>
         <source>Fonts</source>
         <translation>Fonts</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3227"/>
+        <location filename="../src/InfoWidgets.cpp" line="446"/>
         <source>Type 0</source>
         <translation>Tipus 0</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3230"/>
+        <location filename="../src/InfoWidgets.cpp" line="449"/>
         <source>Type 1</source>
         <translation>Tipus 1</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3233"/>
+        <location filename="../src/InfoWidgets.cpp" line="452"/>
         <source>Type 1 (multiple master)</source>
         <translation>Tipus 1 (màster múltiple)</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3236"/>
+        <location filename="../src/InfoWidgets.cpp" line="455"/>
         <source>Type 3</source>
         <translation>Tipus 3</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3239"/>
+        <location filename="../src/InfoWidgets.cpp" line="458"/>
         <source>TrueType</source>
         <translation>TrueType</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
+        <location filename="../src/InfoWidgets.cpp" line="461"/>
         <source>yes</source>
         <translation>sí</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
+        <location filename="../src/InfoWidgets.cpp" line="461"/>
         <source>no</source>
         <translation>no</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3245"/>
+        <location filename="../src/InfoWidgets.cpp" line="464"/>
         <source>[embedded]</source>
         <translation>[incrustat]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3248"/>
+        <location filename="../src/InfoWidgets.cpp" line="467"/>
         <source>[builtin]</source>
         <translation>[order interna]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
+        <location filename="../src/InfoWidgets.cpp" line="491"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
+        <location filename="../src/InfoWidgets.cpp" line="491"/>
         <source>Type</source>
         <translation>Tipus</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
+        <location filename="../src/InfoWidgets.cpp" line="491"/>
         <source>Subset</source>
         <translation>Subconjunt</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
+        <location filename="../src/InfoWidgets.cpp" line="491"/>
         <source>Source</source>
         <translation>Font</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3280"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3375"/>
+        <location filename="../src/InfoWidgets.cpp" line="499"/>
+        <location filename="../src/InfoWidgets.cpp" line="594"/>
         <source>Permissions</source>
         <translation>Permisos</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3329"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3338"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3347"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
+        <location filename="../src/InfoWidgets.cpp" line="548"/>
+        <location filename="../src/InfoWidgets.cpp" line="557"/>
+        <location filename="../src/InfoWidgets.cpp" line="566"/>
+        <location filename="../src/InfoWidgets.cpp" line="573"/>
+        <location filename="../src/InfoWidgets.cpp" line="578"/>
         <source>Allowed</source>
         <translation>Permés</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3331"/>
+        <location filename="../src/InfoWidgets.cpp" line="550"/>
         <source>Low resolution only</source>
         <translation>Només baixa resolució</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3334"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3344"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3356"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3366"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3368"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3370"/>
+        <location filename="../src/InfoWidgets.cpp" line="553"/>
+        <location filename="../src/InfoWidgets.cpp" line="563"/>
+        <location filename="../src/InfoWidgets.cpp" line="570"/>
+        <location filename="../src/InfoWidgets.cpp" line="575"/>
+        <location filename="../src/InfoWidgets.cpp" line="580"/>
+        <location filename="../src/InfoWidgets.cpp" line="585"/>
+        <location filename="../src/InfoWidgets.cpp" line="586"/>
+        <location filename="../src/InfoWidgets.cpp" line="587"/>
+        <location filename="../src/InfoWidgets.cpp" line="588"/>
+        <location filename="../src/InfoWidgets.cpp" line="589"/>
         <source>Denied</source>
         <translation>Denegat</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3340"/>
+        <location filename="../src/InfoWidgets.cpp" line="559"/>
         <source>Assembling only</source>
         <translation>Només assemblat</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
+        <location filename="../src/InfoWidgets.cpp" line="560"/>
         <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
         <translation>Inserir, rotar o eliminar pàgines i crear marcadors o miniatures</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
+        <location filename="../src/InfoWidgets.cpp" line="568"/>
         <source>Accessibility support only</source>
         <translation>Només suport d&apos;accesibilitat</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
+        <location filename="../src/InfoWidgets.cpp" line="596"/>
         <source>Printing:</source>
         <translation>Impressió:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
+        <location filename="../src/InfoWidgets.cpp" line="597"/>
         <source>Modifications:</source>
         <translation>Modificacions:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
+        <location filename="../src/InfoWidgets.cpp" line="598"/>
         <source>Extraction:</source>
         <translation>Extracció:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
+        <location filename="../src/InfoWidgets.cpp" line="599"/>
         <source>Annotation:</source>
         <translation>Anotació:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
+        <location filename="../src/InfoWidgets.cpp" line="600"/>
         <source>Filling forms:</source>
         <translation>Formularis:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3481"/>
+        <location filename="../src/InfoWidgets.cpp" line="608"/>
+        <location filename="../src/InfoWidgets.cpp" line="700"/>
         <source>Annotations</source>
         <translation>Anotacions</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
+        <location filename="../src/InfoWidgets.cpp" line="701"/>
         <source>Page</source>
         <translation>Pàgina</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
+        <location filename="../src/InfoWidgets.cpp" line="701"/>
         <source>Subject</source>
         <translation>Assumpte</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
+        <location filename="../src/InfoWidgets.cpp" line="701"/>
         <source>Author</source>
         <translation>Autor</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
+        <location filename="../src/InfoWidgets.cpp" line="701"/>
         <source>Contents</source>
         <translation>Continguts</translation>
     </message>
